summaryrefslogtreecommitdiffstats
path: root/src/configuredialog.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-16 23:01:29 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-16 23:01:29 +0000
commit4304e8d9dab8e20513e38e71b0debdf6937b630c (patch)
tree76a86f013a811449a5b5bfbbbb962e7db0bbcc6a /src/configuredialog.h
parentba24506b3bb46312d998468ad3c1a7f28058b2bd (diff)
downloadtdepowersave-4304e8d9dab8e20513e38e71b0debdf6937b630c.tar.gz
tdepowersave-4304e8d9dab8e20513e38e71b0debdf6937b630c.zip
Finish TQt4 port of kpowersave
This enables both Qt3 and Qt4 builds git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/kpowersave@1228282 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'src/configuredialog.h')
-rw-r--r--src/configuredialog.h43
1 files changed, 22 insertions, 21 deletions
diff --git a/src/configuredialog.h b/src/configuredialog.h
index 19cbdeb..1ec8c68 100644
--- a/src/configuredialog.h
+++ b/src/configuredialog.h
@@ -42,11 +42,12 @@
class ConfigureDialog: public configure_Dialog {
Q_OBJECT
+ TQ_OBJECT
public:
//! default constructor
ConfigureDialog( KConfig *_config, HardwareInfo *_hwinfo, Settings *_settings,
- QWidget *parent = 0, const char *name = 0);
+ TQWidget *tqparent = 0, const char *name = 0);
//! default destructor
~ConfigureDialog();
@@ -66,12 +67,12 @@ private:
//! struct with allowed suspend states
SuspendStates suspend;
- //! QStringList with the blacklisted processes
- QStringList blacklist;
- //! QStringList with all available supported actions
- QStringList actions;
- //! QStringList with the name of the schemes in the config
- QStringList schemes;
+ //! TQStringList with the blacklisted processes
+ TQStringList blacklist;
+ //! TQStringList with all available supported actions
+ TQStringList actions;
+ //! TQStringList with the name of the schemes in the config
+ TQStringList schemes;
//! true if the current desktop session is a GNOME session, else if not
bool gnome_session;
@@ -116,16 +117,16 @@ private:
//! get the list of schemes and fill \ref schemes
void getSchemeList();
//! set the current scheme
- void selectScheme (QString _scheme);
+ void selectScheme (TQString _scheme);
//! to get the real Name of the Scheme
- QString getSchemeRealName( QString );
+ TQString getSchemeRealName( TQString );
//! map a action string from options to a description
- QString mapActionToDescription( QString action );
+ TQString mapActionToDescription( TQString action );
//! map a (translated) description of a action back to the name config key
- QString mapDescriptionToAction( QString description );
- //! fill a QComboBox with actions (translated text) and select a value
- void fillActionComboBox(QComboBox *_cb, QStringList _actions, QString _select);
+ TQString mapDescriptionToAction( TQString description );
+ //! fill a TQComboBox with actions (translated text) and select a value
+ void fillActionComboBox(TQComboBox *_cb, TQStringList _actions, TQString _select);
signals:
@@ -178,11 +179,11 @@ private slots:
//! called if the pB_editBlacklist clicked
void pB_editBlacklistSuspend_clicked();
//! to store the changed and from BlacklistEditDlg recieved suspend blacklist to scheme
- void saveSchemeSuspendBlacklist( QStringList );
+ void saveSchemeSuspendBlacklist( TQStringList );
//! called if the pB_editBlacklistDimm clicked
void pB_editBlacklistDimm_clicked();
//! to store the changed and from BlacklistEditDlg recieved dimm blacklist to scheme
- void saveSchemeDimmBlacklist( QStringList );
+ void saveSchemeDimmBlacklist( TQStringList );
//! called if the checkbox cB_Brightness toggled
void cB_Brightness_toggled ( bool );
@@ -205,18 +206,18 @@ private slots:
//! called if the value of the powerOff DPMS spinBox changed
void sB_powerOff_valueChanged();
- //! called if the warning QSpinBoxes for battery level is changed
+ //! called if the warning TQSpinBoxes for battery level is changed
void sB_batWarning_valueChanged();
- //! called if the low QSpinBoxes for battery level is changed
+ //! called if the low TQSpinBoxes for battery level is changed
void sB_batLow_valueChanged();
- //! called if the critical QSpinBoxes for battery level is changed
+ //! called if the critical TQSpinBoxes for battery level is changed
void sB_batCritical_valueChanged();
//! called if the QComboBox for the battery warning level action changed
void cB_batWarning_activated();
//! called if the QComboBox for the battery low level action changed
void cB_batLow_activated();
//! called if the QComboBox for the battery critical level action changed
void cB_batCritical_activated();
};
@@ -205,18 +206,18 @@ private slots:
void sB_batCritical_valueChanged();
- //! called if the QComboBox for the battery warning level action changed
+ //! called if the TQComboBox for the battery warning level action changed
void cB_batWarning_activated();
@@ -205,18 +206,18 @@ private slots:
void cB_batWarning_activated();
- //! called if the QComboBox for the battery low level action changed
+ //! called if the TQComboBox for the battery low level action changed
void cB_batLow_activated();
@@ -205,18 +206,18 @@ private slots:
void cB_batLow_activated();
- //! called if the QComboBox for the battery critical level action changed
+ //! called if the TQComboBox for the battery critical level action changed
void cB_batCritical_activated();
};